pub enum ConfigSourceKind {
Tool(ToolName),
ExplicitRepository,
DiscoveredRepository,
}Expand description
How a config file was selected.
The variants are in priority order from lowest to highest.
Variants
Tool(ToolName)
A tool configuration, passed in via --tool-config-file.
ExplicitRepository
An explicit repository configuration, passed in via --config-file.
DiscoveredRepository
The shared repository file found at the workspace root.