pub struct TestSettings<'p, Source = ()> { /* private fields */ }Expand description
Settings for individual tests.
Returned by EvaluatableProfile::settings_for.
The Source parameter tracks an optional source; this isn’t used by any public APIs at the
moment.
Implementations
Sourceimpl<'p> TestSettings<'p>
impl<'p> TestSettings<'p>
Sourcepub fn priority(&self) -> TestPriority
pub fn priority(&self) -> TestPriority
Returns the test’s priority.
Sourcepub fn threads_required(&self) -> ThreadsRequired
pub fn threads_required(&self) -> ThreadsRequired
Returns the number of threads required for this test.
Sourcepub fn run_wrapper(&self) -> Option<&'p WrapperScriptConfig>
pub fn run_wrapper(&self) -> Option<&'p WrapperScriptConfig>
Returns the run-time wrapper script for this test.
Sourcepub fn run_extra_args(&self) -> &'p [String]
pub fn run_extra_args(&self) -> &'p [String]
Returns extra arguments to pass at runtime for this test.
Sourcepub fn retries(&self) -> RetryPolicy
pub fn retries(&self) -> RetryPolicy
Returns the number of retries for this test.
Sourcepub fn flaky_result(&self) -> FlakyResult
pub fn flaky_result(&self) -> FlakyResult
Returns the flaky result behavior for this test.
Sourcepub fn slow_timeout(&self) -> SlowTimeout
pub fn slow_timeout(&self) -> SlowTimeout
Returns the slow timeout for this test.
Sourcepub fn leak_timeout(&self) -> LeakTimeout
pub fn leak_timeout(&self) -> LeakTimeout
Returns the leak timeout for this test.
Sourcepub fn test_group(&self) -> &TestGroup
pub fn test_group(&self) -> &TestGroup
Returns the test group for this test.
Sourcepub fn success_output(&self) -> TestOutputDisplay
pub fn success_output(&self) -> TestOutputDisplay
Returns the success output setting for this test.
Sourcepub fn failure_output(&self) -> TestOutputDisplay
pub fn failure_output(&self) -> TestOutputDisplay
Returns the failure output setting for this test.
Sourcepub fn junit_store_success_output(&self) -> bool
pub fn junit_store_success_output(&self) -> bool
Returns whether success output should be stored in JUnit.
Sourcepub fn junit_store_failure_output(&self) -> bool
pub fn junit_store_failure_output(&self) -> bool
Returns whether failure output should be stored in JUnit.
Sourcepub fn junit_flaky_fail_status(&self) -> JunitFlakyFailStatus
pub fn junit_flaky_fail_status(&self) -> JunitFlakyFailStatus
Returns the JUnit flaky-fail status for this test.