Module scripts

Module scripts 

Support for scripts.

Structs

ScriptCommand
The script command to run.
ScriptCommandEnvMap
A map of environment variables associated with a super::ScriptCommand.
ScriptConfig
Setup and wrapper scripts defined in nextest configuration.
ScriptId
The name of a configuration script.
ScriptInfo
Basic information about a script, used during error checking.
SetupScriptConfig
Deserialized form of setup script configuration before compilation.
SetupScriptJunitConfig
JUnit XML output settings for a setup script.
SetupScripts
Data about setup scripts, returned by an EvaluatableProfile.
WrapperScriptConfig
Deserialized form of wrapper script configuration before compilation.

Enums

ProfileScriptType
A script type as configured in [[profile.*.scripts]].
ScriptCommandRelativeTo
Base directory a relative script program is resolved against.
ScriptType
The script type as configured in the [scripts] table.
WrapperScriptTargetRunner
How a wrapper script composes with a configured target runner.