pub enum ChromeTraceError {
ReadError(RecordReadError),
MissingTestStart {
test_name: TestCaseName,
binary_id: RustBinaryId,
},
MissingScriptStart {
script_id: ScriptId,
},
MissingStressSubRunStart,
SerializeError(Error),
}Expand description
Errors that can occur during Chrome trace conversion.
Variants
ReadError(RecordReadError)
An error occurred while reading recorded events.
MissingTestStart
An event referenced a test that was never started.
MissingScriptStart
A SetupScriptSlow event referenced a script that is not running.
MissingStressSubRunStart
A StressSubRunFinished event arrived without a prior StressSubRunStarted.
SerializeError(Error)
An error occurred while serializing the trace to JSON.