Struct nextest_runner::list::RustBuildMeta
source · [−]pub struct RustBuildMeta<State> {
pub target_directory: Utf8PathBuf,
pub base_output_directories: BTreeSet<Utf8PathBuf>,
pub non_test_binaries: BTreeMap<String, BTreeSet<RustNonTestBinarySummary>>,
pub linked_paths: BTreeMap<Utf8PathBuf, BTreeSet<String>>,
/* private fields */
}Expand description
Rust-related metadata used for builds and test runs.
Fields
target_directory: Utf8PathBufThe target directory for build artifacts.
base_output_directories: BTreeSet<Utf8PathBuf>A list of base output directories, relative to the target directory. These directories and their “deps” subdirectories are added to the dynamic library path.
non_test_binaries: BTreeMap<String, BTreeSet<RustNonTestBinarySummary>>Information about non-test executables, keyed by package ID.
linked_paths: BTreeMap<Utf8PathBuf, BTreeSet<String>>A list of linked paths, relative to the target directory. These directories are added to the dynamic library path.
The values are the package IDs of the libraries that requested the linked paths.
Note that the serialized metadata only has the paths for now, not the libraries that requested them. We might consider adding a new field with metadata about that.
Implementations
sourceimpl RustBuildMeta<BinaryListState>
impl RustBuildMeta<BinaryListState>
sourcepub fn new(target_directory: impl Into<Utf8PathBuf>) -> Self
pub fn new(target_directory: impl Into<Utf8PathBuf>) -> Self
Creates a new RustBuildMeta.
sourcepub fn map_paths(&self, path_mapper: &PathMapper) -> RustBuildMeta<TestListState>
pub fn map_paths(&self, path_mapper: &PathMapper) -> RustBuildMeta<TestListState>
Maps paths using a PathMapper to convert this to TestListState.
sourceimpl RustBuildMeta<TestListState>
impl RustBuildMeta<TestListState>
sourcepub fn dylib_paths(&self) -> Vec<Utf8PathBuf>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
pub fn dylib_paths(&self) -> Vec<Utf8PathBuf>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
Returns the dynamic library paths corresponding to this metadata.
See this Cargo documentation for more.
These paths are prepended to the dynamic library environment variable for the current
platform (e.g. LD_LIBRARY_PATH on non-Apple Unix platforms).
sourceimpl<State> RustBuildMeta<State>
impl<State> RustBuildMeta<State>
sourcepub fn from_summary(summary: RustBuildMetaSummary) -> Self
pub fn from_summary(summary: RustBuildMetaSummary) -> Self
Creates a RustBuildMeta from a serializable summary.
sourcepub fn to_summary(&self) -> RustBuildMetaSummary
pub fn to_summary(&self) -> RustBuildMetaSummary
Converts self to a serializable form.