Struct nextest_runner::platform::Platform
source · [−]pub struct Platform { /* private fields */ }Expand description
A platform to evaluate target specs against.
Implementations
sourceimpl Platform
impl Platform
sourcepub fn new(
triple_str: impl Into<Cow<'static, str>>,
target_features: TargetFeatures
) -> Result<Platform, Error>
pub fn new(
triple_str: impl Into<Cow<'static, str>>,
target_features: TargetFeatures
) -> Result<Platform, Error>
Creates a new Platform from the given triple and target features.
Returns an error if this platform wasn’t known to target-spec.
sourcepub fn current() -> Result<Platform, Error>
pub fn current() -> Result<Platform, Error>
Returns the current platform, as detected at build time.
This will return an error if the current platform was unknown to this version of
target-spec.
sourcepub fn from_triple(triple: Triple, target_features: TargetFeatures) -> Platform
pub fn from_triple(triple: Triple, target_features: TargetFeatures) -> Platform
Creates a new platform from a Triple and target features.
sourcepub fn add_flags(
&mut self,
flags: impl IntoIterator<Item = impl Into<Cow<'static, str>>>
)
pub fn add_flags(
&mut self,
flags: impl IntoIterator<Item = impl Into<Cow<'static, str>>>
)
Adds a set of flags to accept.
A flag is a single token like the foo in cfg(not(foo)).
A default cargo build will always evaluate flags to false, but custom wrappers may cause
some flags to evaluate to true. For example, as of version 0.6, cargo web build will cause
cargo_web to evaluate to true.
sourcepub fn triple_str(&self) -> &str
pub fn triple_str(&self) -> &str
Returns the target triple string for this platform.
sourcepub fn flags(&self) -> impl Iterator<Item = &str> + ExactSizeIterator
pub fn flags(&self) -> impl Iterator<Item = &str> + ExactSizeIterator
Returns the set of flags enabled for this platform.
sourcepub fn has_flag(&self, flag: impl AsRef<str>) -> bool
pub fn has_flag(&self, flag: impl AsRef<str>) -> bool
Returns true if this flag was set with add_flags.
sourcepub fn target_features(&self) -> &TargetFeatures
pub fn target_features(&self) -> &TargetFeatures
Returns the set of target features for this platform.
sourceimpl Platform
impl Platform
sourcepub fn to_summary(&self) -> PlatformSummary
pub fn to_summary(&self) -> PlatformSummary
Converts this Platform to a serializable form.
Requires the summaries feature to be enabled.