pub enum ChildErrorDescription {
ReadStdout {
source: SerializableError,
},
ReadStderr {
source: SerializableError,
},
ReadCombined {
source: SerializableError,
},
Wait {
source: SerializableError,
},
SetupScriptOutput {
source: SerializableError,
},
}Expand description
A serializable description of an error that occurred while managing a child process.
This is the external-facing counterpart to ChildError.
Variants
ReadStdout
An error occurred while reading standard output.
Fields

source: SerializableErrorThe source error.
ReadStderr
An error occurred while reading standard error.
Fields

source: SerializableErrorThe source error.
ReadCombined
An error occurred while reading combined output.
Fields

source: SerializableErrorThe source error.
Wait
An error occurred while waiting for the child process to exit.
Fields

source: SerializableErrorThe source error.
SetupScriptOutput
An error occurred while reading the output of a setup script.
Fields

source: SerializableErrorThe source error.