StressProgress

Enum StressProgress 

pub enum StressProgress {
    Count {
        total: StressCount,
        elapsed: Duration,
        completed: u32,
    },
    Time {
        total: Duration,
        elapsed: Duration,
        completed: u32,
    },
}
Progress for a stress test.

Variants



Count

This is a count-based stress run.

Fields

total: StressCount

The total number of stress runs.

elapsed: Duration

The total time that has elapsed across all stress runs so far.

completed: u32

The number of stress runs that have been completed.



Time

This is a time-based stress run.

Fields

total: Duration

The total time for the stress run.

elapsed: Duration

The total time that has elapsed across all stress runs so far.

completed: u32

The number of stress runs that have been completed.

Implementations

Source

impl StressProgress

pub fn remaining(&self) -> Option<StressRemaining>

Returns the remaining amount of work if the progress indicates there’s still more to do, otherwise None.

pub fn unique_id(&self, run_id: ReportUuid) -> String

Returns a unique ID for this stress sub-run, consisting of the run ID and stress index.