pub struct SerializableError { /* private fields */ }Expand description
A serializable representation of an error chain.
This captures the error message and the chain of source errors from
any std::error::Error implementation.
Implementations
Sourceimpl SerializableError
impl SerializableError
Sourcepub fn new(error: &dyn Error) -> Self
pub fn new(error: &dyn Error) -> Self
Creates a new SerializableError from an error, walking the
full source chain.
Sourcepub fn from_message_and_causes(message: String, causes: Vec<String>) -> Self
pub fn from_message_and_causes(message: String, causes: Vec<String>) -> Self
Creates a new SerializableError from a message and a list of
causes.
Sourcepub fn sources(&self) -> SerializableErrorSources<'_> ⓘ
pub fn sources(&self) -> SerializableErrorSources<'_> ⓘ
Returns the causes of this error as an iterator.