pub struct ArchiveCounts {
pub test_binary_count: usize,
pub filter_counts: ArchiveFilterCounts,
pub non_test_binary_count: usize,
pub build_script_out_dir_count: usize,
pub linked_path_count: usize,
pub extra_path_count: usize,
pub stdlib_count: usize,
}Expand description
Counts of various types of files in an archive.
Fields
test_binary_count: usizeThe number of test binaries that will be included in the archive, not including filtered out test binaries.
filter_counts: ArchiveFilterCountsCounts for filtered out binaries.
non_test_binary_count: usizeThe number of non-test binaries.
build_script_out_dir_count: usizeThe number of build script output directories.
linked_path_count: usizeThe number of linked paths.
extra_path_count: usizeThe number of extra paths.
stdlib_count: usizeThe number of standard libraries.