Struct nextest_runner::runner::RunStats
source · pub struct RunStats {
pub initial_run_count: usize,
pub finished_count: usize,
pub passed: usize,
pub passed_slow: usize,
pub flaky: usize,
pub failed: usize,
pub failed_slow: usize,
pub timed_out: usize,
pub leaky: usize,
pub exec_failed: usize,
pub skipped: usize,
}Expand description
Statistics for a test run.
Fields
initial_run_count: usizeThe total number of tests that were expected to be run at the beginning.
If the test run is canceled, this will be more than finished_count at the end.
finished_count: usizeThe total number of tests that finished running.
passed: usizeThe number of tests that passed. Includes passed_slow, flaky and leaky.
passed_slow: usizeThe number of slow tests that passed.
flaky: usizeThe number of tests that passed on retry.
failed: usizeThe number of tests that failed.
failed_slow: usizeThe number of failed tests that were slow.
timed_out: usizeThe number of tests that timed out.
leaky: usizeThe number of tests that passed but leaked handles.
exec_failed: usizeThe number of tests that encountered an execution failure.
skipped: usizeThe number of tests that were skipped.
Implementations
sourceimpl RunStats
impl RunStats
sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns true if this run is considered a success.
A run can be marked as failed if any of the following are true:
- the run was canceled: the initial run count is greater than the final run count
- any tests failed
- any tests encountered an execution failure
sourcepub fn any_failed(&self) -> bool
pub fn any_failed(&self) -> bool
Returns true if any tests failed or were timed out.