pub struct TestFilter { /* private fields */ }Expand description
Filter for selecting which tests to run.
Constructed via TestFilter::new.
Implementations
Sourceimpl TestFilter
impl TestFilter
Sourcepub fn new(
mode: NextestRunMode,
run_ignored: RunIgnored,
patterns: TestFilterPatterns,
exprs: Vec<Filterset>,
) -> Result<Self, TestFilterBuildError>
pub fn new( mode: NextestRunMode, run_ignored: RunIgnored, patterns: TestFilterPatterns, exprs: Vec<Filterset>, ) -> Result<Self, TestFilterBuildError>
Creates a new TestFilter from the given patterns.
If an empty slice is passed, the test filter matches all possible test names.
Sourcepub fn filter_binary_match(
&self,
test_binary: &RustTestArtifact<'_>,
ecx: &EvalContext<'_>,
bound: FilterBound,
) -> FilterBinaryMatch
pub fn filter_binary_match( &self, test_binary: &RustTestArtifact<'_>, ecx: &EvalContext<'_>, bound: FilterBound, ) -> FilterBinaryMatch
Returns a value indicating whether this binary should or should not be run to obtain the list of tests within it.
Sourcepub fn default_set(mode: NextestRunMode, run_ignored: RunIgnored) -> Self
pub fn default_set(mode: NextestRunMode, run_ignored: RunIgnored) -> Self
Creates a new TestFilter that matches the default set of tests.
Sourcepub fn set_outstanding_tests(&mut self, rerun_info: ComputedRerunInfo)
pub fn set_outstanding_tests(&mut self, rerun_info: ComputedRerunInfo)
Sets the list of outstanding tests, if this is a rerun.
Sourcepub fn mode(&self) -> NextestRunMode
pub fn mode(&self) -> NextestRunMode
Returns the nextest execution mode.
Sourcepub fn patterns_eq(&self, other: &Self) -> bool
pub fn patterns_eq(&self, other: &Self) -> bool
Compares the patterns between two TestFilters.
Sourcepub fn into_rerun_info(self) -> Option<ComputedRerunInfo>
pub fn into_rerun_info(self) -> Option<ComputedRerunInfo>
Consumes self, returning the underlying ComputedRerunInfo if any.
Sourcepub fn filter_match(
&self,
test_binary: &RustTestArtifact<'_>,
test_name: &TestCaseName,
test_kind: &RustTestKind,
ecx: &EvalContext<'_>,
bound: FilterBound,
ignored: bool,
) -> FilterMatch
pub fn filter_match( &self, test_binary: &RustTestArtifact<'_>, test_name: &TestCaseName, test_kind: &RustTestKind, ecx: &EvalContext<'_>, bound: FilterBound, ignored: bool, ) -> FilterMatch
Returns an enum describing the match status of this filter.