PrereleaseKind

Enum PrereleaseKind 

pub enum PrereleaseKind {
    Beta,
    Rc,
}
The kind of prerelease to look for.

Variants



Beta

Beta channel (includes beta -b.N, RC -rc.N, and stable versions).



Rc

Release candidate channel (-rc.N and stable versions).

Implementations

Source

impl PrereleaseKind

pub fn matches(&self, version: &Version) -> bool

Returns true if this version is acceptable for this prerelease kind.

Beta accepts stable, RC, or beta versions.

Rc accepts stable or RC versions (not beta).

pub fn description(&self) -> &'static str

Returns a description of this prerelease kind for user-facing messages.