Struct nextest_runner::config::NextestConfig
source · pub struct NextestConfig { /* private fields */ }Expand description
Overall configuration for nextest.
This is the root data structure for nextest configuration. Most runner-specific configuration is managed
through profiles, obtained through the profile method.
For more about configuration, see Configuration in the nextest book.
Implementations
sourceimpl NextestConfig
impl NextestConfig
sourcepub const CONFIG_PATH: &'static str = ".config/nextest.toml"
pub const CONFIG_PATH: &'static str = ".config/nextest.toml"
The default location of the config within the path: .config/nextest.toml, used to read the
config from the given directory.
sourcepub const DEFAULT_CONFIG: &'static str = _
pub const DEFAULT_CONFIG: &'static str = _
Contains the default config as a TOML file.
Repository-specific configuration is layered on top of the default config.
sourcepub const ENVIRONMENT_PREFIX: &'static str = "NEXTEST"
pub const ENVIRONMENT_PREFIX: &'static str = "NEXTEST"
Environment configuration uses this prefix, plus a _.
sourcepub const DEFAULT_PROFILE: &'static str = "default"
pub const DEFAULT_PROFILE: &'static str = "default"
The name of the default profile.
sourcepub const DEFAULT_MIRI_PROFILE: &'static str = "default-miri"
pub const DEFAULT_MIRI_PROFILE: &'static str = "default-miri"
The name of the default profile used for miri.
sourcepub const DEFAULT_PROFILES: &'static [&'static str] = _
pub const DEFAULT_PROFILES: &'static [&'static str] = _
A list containing the names of the Nextest defined reserved profile names.
sourcepub fn from_sources<'a, I>(
workspace_root: impl Into<Utf8PathBuf>,
graph: &PackageGraph,
config_file: Option<&Utf8Path>,
tool_config_files: impl IntoIterator<IntoIter = I>
) -> Result<Self, ConfigParseError>where
I: Iterator<Item = &'a ToolConfigFile> + DoubleEndedIterator,
pub fn from_sources<'a, I>( workspace_root: impl Into<Utf8PathBuf>, graph: &PackageGraph, config_file: Option<&Utf8Path>, tool_config_files: impl IntoIterator<IntoIter = I> ) -> Result<Self, ConfigParseError>where I: Iterator<Item = &'a ToolConfigFile> + DoubleEndedIterator,
Reads the nextest config from the given file, or if not specified from .config/nextest.toml
in the workspace root.
tool_config_files are lower priority than config_file but higher priority than the
default config. Files in tool_config_files that come earlier are higher priority than those
that come later.
If no config files are specified and this file doesn’t have .config/nextest.toml, uses the
default config options.
sourcepub fn profile(
&self,
name: impl AsRef<str>
) -> Result<NextestProfile<'_, PreBuildPlatform>, ProfileNotFound>
pub fn profile( &self, name: impl AsRef<str> ) -> Result<NextestProfile<'_, PreBuildPlatform>, ProfileNotFound>
Returns the profile with the given name, or an error if a profile was specified but not found.