#[non_exhaustive]pub enum ConfigParseErrorKind {
BuildError(Box<ConfigError>),
DeserializeError(Box<Error<ConfigError>>),
VersionOnlyReadError(Error),
VersionOnlyDeserializeError(Box<Error<Error>>),
OverrideError(Vec<ConfigParseOverrideError>),
InvalidTestGroupsDefined(BTreeSet<CustomTestGroup>),
InvalidTestGroupsDefinedByTool(BTreeSet<CustomTestGroup>),
UnknownTestGroups {
errors: Vec<UnknownTestGroupError>,
known_groups: BTreeSet<TestGroup>,
},
}Expand description
The kind of error that occurred while parsing a config.
Returned by ConfigParseError::kind.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BuildError(Box<ConfigError>)
An error occurred while building the config.
DeserializeError(Box<Error<ConfigError>>)
An error occurred while deserializing the config.
VersionOnlyReadError(Error)
An error occurred while reading the config file (version only).
VersionOnlyDeserializeError(Box<Error<Error>>)
An error occurred while deserializing the config (version only).
OverrideError(Vec<ConfigParseOverrideError>)
Errors occurred while parsing overrides.
InvalidTestGroupsDefined(BTreeSet<CustomTestGroup>)
An invalid set of test groups was defined by the user.
InvalidTestGroupsDefinedByTool(BTreeSet<CustomTestGroup>)
An invalid set of test groups was defined by a tool config file.
UnknownTestGroups
Fields

errors: Vec<UnknownTestGroupError>The list of errors that occurred.
Some test groups were unknown.