pub enum ExecutionDescription<'a, S: OutputSpec> {
Success {
single_status: &'a ExecuteStatus<S>,
},
Flaky {
last_status: &'a ExecuteStatus<S>,
prior_statuses: &'a [ExecuteStatus<S>],
},
Failure {
first_status: &'a ExecuteStatus<S>,
last_status: &'a ExecuteStatus<S>,
retries: &'a [ExecuteStatus<S>],
},
}Expand description
A description of test executions obtained from ExecuteStatuses.
This can be used to quickly determine whether a test passed, failed or was flaky.
The type parameter S specifies how test output is stored (see
OutputSpec).
Variants
Success
The test was run once and was successful.
Fields
single_status: &'a ExecuteStatus<S>The status of the test.
Flaky
The test was run more than once. The final result was successful.
Fields
last_status: &'a ExecuteStatus<S>The last, successful status.
prior_statuses: &'a [ExecuteStatus<S>]Previous statuses, none of which are successes.
Failure
The test was run once, or possibly multiple times. All runs failed.
Fields
first_status: &'a ExecuteStatus<S>The first, failing status.
last_status: &'a ExecuteStatus<S>The last, failing status. Same as the first status if no retries were performed.
retries: &'a [ExecuteStatus<S>]Any retries that were performed. All of these runs failed.
May be empty.
Implementations
Sourceimpl<'a, S: OutputSpec> ExecutionDescription<'a, S>
impl<'a, S: OutputSpec> ExecutionDescription<'a, S>
Sourcepub fn status_level(&self) -> StatusLevel
pub fn status_level(&self) -> StatusLevel
Returns the status level for this ExecutionDescription.
Sourcepub fn final_status_level(&self) -> FinalStatusLevel
pub fn final_status_level(&self) -> FinalStatusLevel
Returns the final status level for this ExecutionDescription.
Sourcepub fn last_status(&self) -> &'a ExecuteStatus<S>
pub fn last_status(&self) -> &'a ExecuteStatus<S>
Returns the last run status.