pub struct OutputLoadDecider { /* private fields */ }Expand description
Configuration needed to decide whether to load output during replay.
This captures the reporter’s display configuration so the replay loop can
skip decompressing output from the archive when it will never be shown. The
decision is conservative: LoadOutput::Load is returned whenever there is
any chance the output will be displayed, either immediately or at the end of
the run.
Currently, replays only use a display reporter, and do not use JUnit or libtest reporters. If and when support for those is added to replay, this decider must be updated to account for their output requirements as well.
Implementations
Sourceimpl OutputLoadDecider
impl OutputLoadDecider
Sourcepub fn should_load_output(
&self,
kind: &OutputEventKind<RecordingSpec>,
) -> LoadOutput
pub fn should_load_output( &self, kind: &OutputEventKind<RecordingSpec>, ) -> LoadOutput
Decides whether output should be loaded for a given output event.